==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/UserFactorTokenFactorVerificationObject.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorTokenFactorVerificationObject
 */
@JsonPropertyOrder({ UserFactorTokenFactorVerificationObject.JSON_PROPERTY_NEXT_PASS_CODE,
        UserFactorTokenFactorVerificationObject.JSON_PROPERTY_PASS_CODE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserFactorTokenFactorVerificationObject implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_NEXT_PASS_CODE = "nextPassCode";
    private String nextPassCode;

    public static final String JSON_PROPERTY_PASS_CODE = "passCode";
    private String passCode;

    public UserFactorTokenFactorVerificationObject() {
    }

    public UserFactorTokenFactorVerificationObject nextPassCode(String nextPassCode) {

        this.nextPassCode = nextPassCode;
        return this;
    }

    /**
     * OTP for the next time window
     *
     * @return nextPassCode
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "678195", value = "OTP for the next time window")
    @JsonProperty(JSON_PROPERTY_NEXT_PASS_CODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getNextPassCode() {
        return nextPassCode;
    }

    @JsonProperty(JSON_PROPERTY_NEXT_PASS_CODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setNextPassCode(String nextPassCode) {
        this.nextPassCode = nextPassCode;
    }

    public UserFactorTokenFactorVerificationObject passCode(String passCode) {

        this.passCode = passCode;
        return this;
    }

    /**
     * OTP for the current time window
     *
     * @return passCode
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "875498", value = "OTP for the current time window")
    @JsonProperty(JSON_PROPERTY_PASS_CODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getPassCode() {
        return passCode;
    }

    @JsonProperty(JSON_PROPERTY_PASS_CODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPassCode(String passCode) {
        this.passCode = passCode;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorTokenFactorVerificationObject userFactorTokenFactorVerificationObject = (UserFactorTokenFactorVerificationObject) o;
        return Objects.equals(this.nextPassCode, userFactorTokenFactorVerificationObject.nextPassCode)
                && Objects.equals(this.passCode, userFactorTokenFactorVerificationObject.passCode);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(nextPassCode, passCode);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorTokenFactorVerificationObject {\n");
        sb.append("    nextPassCode: ").append(toIndentedString(nextPassCode)).append("\n");
        sb.append("    passCode: ").append(toIndentedString(passCode)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/UserFactorTokenFactorVerificationObject.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorTokenFactorVerificationObject
 */
@JsonPropertyOrder({ UserFactorTokenFactorVerificationObject.JSON_PROPERTY_NEXT_PASS_CODE,
        UserFactorTokenFactorVerificationObject.JSON_PROPERTY_PASS_CODE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class UserFactorTokenFactorVerificationObject implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_NEXT_PASS_CODE = "nextPassCode";
    private String nextPassCode;

    public static final String JSON_PROPERTY_PASS_CODE = "passCode";
    private String passCode;

    public UserFactorTokenFactorVerificationObject() {
    }

    public UserFactorTokenFactorVerificationObject nextPassCode(String nextPassCode) {

        this.nextPassCode = nextPassCode;
        return this;
    }

    /**
     * OTP for the next time window
     *
     * @return nextPassCode
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "678195", value = "OTP for the next time window")
    @JsonProperty(JSON_PROPERTY_NEXT_PASS_CODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getNextPassCode() {
        return nextPassCode;
    }

    @JsonProperty(JSON_PROPERTY_NEXT_PASS_CODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setNextPassCode(String nextPassCode) {
        this.nextPassCode = nextPassCode;
    }

    public UserFactorTokenFactorVerificationObject passCode(String passCode) {

        this.passCode = passCode;
        return this;
    }

    /**
     * OTP for the current time window
     *
     * @return passCode
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "875498", value = "OTP for the current time window")
    @JsonProperty(JSON_PROPERTY_PASS_CODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getPassCode() {
        return passCode;
    }

    @JsonProperty(JSON_PROPERTY_PASS_CODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPassCode(String passCode) {
        this.passCode = passCode;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorTokenFactorVerificationObject userFactorTokenFactorVerificationObject = (UserFactorTokenFactorVerificationObject) o;
        return Objects.equals(this.nextPassCode, userFactorTokenFactorVerificationObject.nextPassCode)
                && Objects.equals(this.passCode, userFactorTokenFactorVerificationObject.passCode);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(nextPassCode, passCode);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorTokenFactorVerificationObject {\n");
        sb.append("    nextPassCode: ").append(toIndentedString(nextPassCode)).append("\n");
        sb.append("    passCode: ").append(toIndentedString(passCode)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
